pub(crate) fn init_logger()Expand description
Creates a pretty_env_logger logger if no log
logger is found to be initialized in this process.
pub(crate) fn init_logger()Creates a pretty_env_logger logger if no log
logger is found to be initialized in this process.